@@ -18,7 +18,7 @@
 
      For further information visit http://plib.sourceforge.net
 
-     $Id: jsLinux.cxx,v 1.6 2004/10/20 23:49:33 wolfram_kuss Exp $
+     $Id: jsLinux.cxx 2017 2005-02-21 07:37:25Z bram $
 */
 
 #include "js.h"
@@ -75,12 +75,13 @@ void jsJoystick::open ()
   ioctl ( os->fd, JSIOCGNAME ( sizeof(name) ), name ) ;
   fcntl ( os->fd, F_SETFL      , O_NONBLOCK   ) ;
 
+  int all_axes = num_axes;
   if ( num_axes > _JS_MAX_AXES )
     num_axes = _JS_MAX_AXES ;
 
   // Remove any deadband value already done in the kernel.
   // Since we have our own deadband management this is save to do so.
-  struct js_corr corr [ _JS_MAX_AXES ] ;
+  struct js_corr* corr = new js_corr[ all_axes ] ;
   ioctl ( os->fd, JSIOCGCORR, corr );
   for ( int i = 0; i < num_axes ; ++i ) {
     if ( corr[ i ] . type == JS_CORR_BROKEN ) {
@@ -90,6 +91,7 @@ void jsJoystick::open ()
     }
   }
   ioctl ( os->fd, JSIOCSCORR, corr );
+  delete [] corr;
 
   for ( int i = 0 ; i < _JS_MAX_AXES ; i++ )
   {
