@@ -18,7 +18,7 @@
  
      For further information visit http://plib.sourceforge.net
 
-     $Id: sg.h,v 1.59 2004/04/06 12:53:16 sjbaker Exp $
+     $Id: sg.h 2121 2007-09-15 03:36:21Z fayjf $
 */
 
 
@@ -138,6 +138,10 @@ inline SGfloat sgHeightOfPlaneVec2 ( const sgVec4 plane, const sgVec2 pnt )
 /*
   Convert a direction vector into a set of euler angles,
   (with zero roll)
+  The direction vector is X-coordinate = north, Y-coordinate = east, Z-coordinate = down
+  The heading ( = hpr[0] ) is in degrees south of east -- this is VERY nonstandard
+  The pitch ( = hpr[1] ) is in degrees positive up
+  The roll ( = hpr[2] ) is zero
 */
 
 extern void sgHPRfromVec3 ( sgVec3 hpr, const sgVec3 src ) ;
@@ -1059,6 +1063,11 @@ class sgFrustum
   sgVec4 plane [ 6 ] ;
 
   /* These two are only valid for simple frusta */
+  /* Note that to convert to parameters for gluPerspective you do the following:
+   *   "fovy" is "vfov"
+   *   "aspect" is the ratio "hfov" / "vfov"
+   * Note also that the "hfov" and "vfov" variables are NOT automatically set.
+   */
 
   SGfloat hfov ;    /* Horizontal Field of View  -or-  Orthographic Width  */
   SGfloat vfov ;    /* Vertical   Field of View  -or-  Orthographic Height */
