@@ -18,7 +18,7 @@
 
      For further information visit http://plib.sourceforge.net
 
-     $Id: ssg.cxx,v 1.70 2004/10/29 22:24:08 wolfram_kuss Exp $
+     $Id: ssg.cxx 2125 2007-09-29 17:20:40Z fayjf $
 */
 
 
@@ -476,3 +476,43 @@ ssgBase *ssgCreateOfType ( int type )
 
   return obj ;
 }
+
+static bool ssgSearchExtensionString(char *extString, char *extName)
+{
+  // Returns GL_TRUE if the *extName string appears in the *extString string,
+  // surrounded by white spaces, or GL_FALSE otherwise.
+
+  char *p, *end;
+  int n, extNameLen;
+
+  if ( ( extString == NULL ) || ( extName == NULL ) )
+    return false;
+
+  extNameLen = strlen ( extName );
+
+  p = extString;
+  end = p + strlen ( p );
+
+  while ( p < end )
+  {
+    n = strcspn ( p, " " );
+    if ( ( extNameLen == n ) && ( strncmp ( extName, p, n ) == 0 ) )
+      return GL_TRUE;
+
+    p += (n + 1);
+  }
+
+  return GL_FALSE;
+}
+
+bool ssgIsExtensionSupported(char *extName)
+{
+  // Returns GL_TRUE if the OpenGL Extension whose name is *extName
+  // is supported by the system, or GL_FALSE otherwise.
+
+  // The *extName string must follow the OpenGL extensions naming scheme
+  // (ie: "GL_type_extension", like GL_EXT_convolution)
+
+  return ssgSearchExtensionString ( (char *)glGetString(GL_EXTENSIONS), extName );
+}
+
