@@ -18,7 +18,7 @@
  
      For further information visit http://plib.sourceforge.net
 
-     $Id: ssgSaveAC.cxx,v 1.21 2004/12/01 08:28:05 wolfram_kuss Exp $
+     $Id: ssgSaveAC.cxx 2117 2007-09-13 23:21:09Z fayjf $
 */
 
 
@@ -87,17 +87,9 @@ static int ssgSaveLeaf ( ssgEntity *ent )
         if ( writeTextureWithoutPath )
         {
 
-#ifdef UL_BB
-          char *s = strrchr ( (char*)tfname, '\\' ) ;
-#else
-          char *s = strrchr ( tfname, '\\' ) ;
-#endif
+          const char *s = strrchr ( tfname, '\\' ) ;
           if ( s == NULL )
-#ifdef UL_BB
-            s = strrchr ( (char*)tfname, '/' ) ;
-#else
             s = strrchr ( tfname, '/' ) ;
-#endif
 
           if ( s == NULL )
             fprintf ( save_fd, "texture \"%s\"\n", tfname ) ;
